<?php
/**
 * Plugin Name: WooCommerce Product Accordion
 * Description: WooCommerce Product Accordion
 * Plugin URI:  https://bestwpdeveloper.com/woocommerce-product-accordion
 * Version:     1.0
 * Author:      20script
 * Author URI:  https://www.20script.ir
 * Text Domain: woocommerce-product-accordion
 * Elementor tested up to: 3.0.0
 * Elementor Pro tested up to: 3.0.0
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
require_once ( plugin_dir_path(__FILE__) ) . '/includes/requires-check.php';
final class WOOCPAAccordion_Creator{

	const VERSION = '1.0';

	const MINIMUM_ELEMENTOR_VERSION = '3.0.0';

	const MINIMUM_PHP_VERSION = '7.0';

	public function __construct() {

		// Load translation
		add_action( 'woocpa_init', array( $this, 'woocpa_loaded_textdomain' ) );
		// woocpa_init Plugin
		add_action( 'plugins_loaded', array( $this, 'woocpa_init' ) );
		// For woocommerce install check
		if ( ! did_action( 'woocommerce/loaded' ) ) {
			add_action( 'admin_notices', 'woocpa_WooCommerce_register_required_plugins' );
			return;
		}
	}

	public function woocpa_loaded_textdomain() {
		load_plugin_textdomain( 'woocommerce-product-accordion' );
	}

	public function woocpa_init() {

		// Check if Elementor installed and activated
		if ( ! did_action( 'elementor/loaded' ) ) {
			add_action( 'admin_notices', 'woocpa_admin_notice_missing_main_plugin');
			return;
		}

		// Check for required Elementor version
		if ( ! version_compare( ELEMENTOR_VERSION, self::MINIMUM_ELEMENTOR_VERSION, '>=' ) ) {
			add_action( 'admin_notices', array( $this, 'woocpa_admin_notice_minimum_elementor_version' ) );
			return;
		}

		// Check for required PHP version
		if ( version_compare( PHP_VERSION, self::MINIMUM_PHP_VERSION, '<' ) ) {
			add_action( 'admin_notices', array( $this, 'woocpa_admin_notice_minimum_php_version' ) );
			return;
		}

		// Once we get here, We have passed all validation checks so we can safely include our plugin
		require_once( 'woocpa-accordion-boots.php' );
	}

	public function woocpa_admin_notice_missing_main_plugin() {
		if ( isset( $_GET['activate'] ) ) {
			unset( $_GET['activate'] );
		}

		$message = sprintf(
			esc_html__( '"%1$s" requires "%2$s" to be installed and activated.', 'woocommerce-product-accordion' ),
			'<strong>' . esc_html__( 'WooCommerce Product Accordion', 'woocommerce-product-accordion' ) . '</strong>',
			'<strong>' . esc_html__( 'Elementor', 'woocommerce-product-accordion' ) . '</strong>'
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>' . esc_html__('%1$s', 'woocommerce-product-accordion') . '</p></div>', $message );
	}

	public function woocpa_admin_notice_minimum_elementor_version() {
		if ( isset( $_GET['activate'] ) ) {
			unset( $_GET['activate'] );
		}

		$message = sprintf(
			esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'woocommerce-product-accordion' ),
			'<strong>' . esc_html__( 'WooCommerce Product Accordion', 'woocommerce-product-accordion' ) . '</strong>',
			'<strong>' . esc_html__( 'Elementor', 'woocommerce-product-accordion' ) . '</strong>',
			self::MINIMUM_ELEMENTOR_VERSION
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>' . esc_html__('%1$s', 'woocommerce-product-accordion') . '</p></div>', $message );
	}

	public function woocpa_admin_notice_minimum_php_version() {
		if ( isset( $_GET['activate'] ) ) {
			unset( $_GET['activate'] );
		}

		$message = sprintf(
			esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'woocommerce-product-accordion' ),
			'<strong>' . esc_html__( 'WooCommerce Product Accordion', 'woocommerce-product-accordion' ) . '</strong>',
			'<strong>' . esc_html__( 'PHP', 'woocommerce-product-accordion' ) . '</strong>',
			self::MINIMUM_PHP_VERSION
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>' . esc_html__('%1$s', 'woocommerce-product-accordion') . '</p></div>', $message );
	}
}

// Instantiate woocommerce-product-accordion.
new WOOCPAAccordion_Creator();
remove_action( 'shutdown', 'wp_ob_end_flush_all', 1 );