<?php
namespace WOOCPANamespaceAccordion;

use WOOCPANamespaceAccordion\PageSettings\Page_Settings;
define('WOOCPA_ACCORDION_PUBLIC_ASSETS_ALL', plugin_dir_url(__FILE__) . 'assets/public');
define('WOOCPA_TEST_ASFSK_ASSETS_ADMIN_DIR_FILE', plugin_dir_url(__FILE__) . 'assets/admin');
class WOOCPAAccordionCreator {

	private static $_instance = null;

	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	public function woocpa_admin_editor_scripts() {
		add_filter( 'script_loader_tag', [ $this, 'woocpa_admin_editor_scripts_as_a_module' ], 10, 2 );
	}

	public function woocpa_admin_editor_scripts_as_a_module( $tag, $handle ) {
		if ( 'woocpa_accordion_editor' === $handle ) {
			$tag = str_replace( '<script', '<script type="module"', $tag );
		}

		return $tag;
	}

	private function include_widgets_files() {
		require_once( __DIR__ . '/widgets/woocpa-accordion.php' );
	}

	public function woocpa_register_widgets() {
		// Its is now safe to include Widgets files
		$this->include_widgets_files(); 

		// Register Widgets
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\WOOCPAAccordionCreatoR() );
	}

	private function add_page_settings_controls() {
		require_once( __DIR__ . '/page-settings/woocpa-accordion-manager.php' );
		new Page_Settings();
	}

	// Register Category
	function woocpa_add_elementor_widget_categories( $elements_manager ) {

		$elements_manager->add_category(
			'woocpa-woocommerce-product-accordion-category',
			[
				'title' => esc_html__( 'WooCommerce Product Accordion', 'woocommerce-product-accordion' ),
				'icon' => 'eicon-person',
			]
		);
	}
	public function woocpa_all_assets_for_the_public(){
		wp_enqueue_script( 'woocpa_accordion_main_js', plugin_dir_url( __FILE__ ) . 'assets/public/js/woocpa-main.js', array('jquery'), '1.0', true );
		wp_enqueue_style( 'woocpa-fontawesome-css', 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.8.2/css/all.min.css', array(), '5.8.2', 'all' );
		$all_css_js_file = array(
            'woocpa_accordion_main_css' => array('woocpa_path_define_with_accordion'=>WOOCPA_ACCORDION_PUBLIC_ASSETS_ALL . '/css/woocpa-main.css'),
        );

        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['woocpa_path_define_with_accordion'], null, '1.0', 'all');
            wp_enqueue_script( $handle, $fileinfo['woocpa_path_define_with_accordion'], '1.0', true);
        }
	}
	public function woocpa_all_assets_for_elementor_editor_admin(){
		$all_css_js_file = array(
            'woocpa_accordion_admin_main_css' => array('woocpa_path_admin_define'=>WOOCPA_TEST_ASFSK_ASSETS_ADMIN_DIR_FILE . '/icon.css'),
        );
        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['woocpa_path_admin_define'], null, '1.0', 'all');
        }
	}

	public function __construct() {
		// For public assets
		add_action('wp_enqueue_scripts', [$this, 'woocpa_all_assets_for_the_public']);

		// For Elementor Editor
		add_action('elementor/editor/before_enqueue_scripts', [$this, 'woocpa_all_assets_for_elementor_editor_admin']);

		// Register Category
		add_action( 'elementor/elements/categories_registered', [ $this, 'woocpa_add_elementor_widget_categories' ] );

		// Register widgets
		add_action( 'elementor/widgets/widgets_registered', [ $this, 'woocpa_register_widgets' ] );

		// Register editor scripts
		add_action( 'elementor/editor/after_enqueue_scripts', [ $this, 'woocpa_admin_editor_scripts' ] );
		
		$this->add_page_settings_controls();
	}
}

// Instantiate Plugin Class
WOOCPAAccordionCreator::instance();
